@@ -14,6 +14,7 @@ __all__ = (
     "Warlock",
     "Wizard",
     "RevisedRanger",
+    "BloodHunter",
     "available_classes",
 )
 
@@ -24,6 +25,7 @@ from dungeonsheets.classes.classes import CharClass
 from dungeonsheets.classes.cleric import Cleric
 from dungeonsheets.classes.druid import Druid
 from dungeonsheets.classes.fighter import Fighter
+from dungeonsheets.classes.bloodhunter import BloodHunter
 from dungeonsheets.classes.monk import Monk
 from dungeonsheets.classes.paladin import Paladin
 from dungeonsheets.classes.ranger import Ranger, RevisedRanger
@@ -47,4 +49,5 @@ available_classes = [
     Warlock,
     Wizard,
     RevisedRanger,
+    BloodHunter,
 ]
