@@ -360,6 +360,18 @@ class InsightfulFighting(Feature):
     source = "Rogue (Inquisitive)"
 
 
+# Optional class feature from *Tasha's Guide to Everything*
+class SteadyAim(Feature):
+    """As a bonus action, you give yourself advantage on your next attack
+    roll on the current turn. You can use this bonus action only if
+    you haven't moved during this turn, and after you use the bonus
+    action, your speed is 0 until the end of the current turn.
+    
+    """
+    name = "Steady Aim"
+    source = "Rogue (3rd level, optional)"
+
+
 class SteadyEye(Feature):
     """Starting at 9th level, you have advantage on any Wisdom (Perception) or
     Intelligence (Investigation) check if you move no more than half your speed
@@ -610,3 +622,134 @@ class MasterDuelist(Feature):
 
     name = "Master Duelist"
     source = "Rogue (Swashbuckler)"
+
+
+# Soulknife
+class PsionicPower(Feature):
+    """You harbor a wellspring of psionic energy within yourself. This·
+    energy is represented by your Psionic Energy dice, which are each
+    a ``d6``. You have a number of these dice equal to twice your
+    proficiency bonus, and they fuel various psionic powers you have,
+    which are detailed below.
+    
+    Some of your powers expend the Psionic Energy die they use, as
+    specified in a power's description, and you can't use a power if
+    it requires you to use a die when your dice are all expended. You
+    regain all your expended Psionic Energy dice when you finish a
+    long rest. In addition, as a bonus action, you can regain one
+    expended Psionic Energy die, but you can't do so again until you
+    finish a short or long rest.
+    
+    When you reach certain levels in this class, the size of your
+    Psionic Energy dice increases: at 5th level (``d8``), 11th level
+    (``dlO``), and 17th level (``d12``).
+    
+    The powers below use your Psionic Energy dice.
+    
+    Psi-Bolstered Knack
+      When your nonpsionic training fails you, your psionic power can
+      help: if you fail an ability check using a skill or tool with
+      which you have proficiency, you can roll one Psionic Energy die
+      and add the number rolled to the check, potentially turning
+      failure into success. You expend the die only if the roll
+      succeeds.
+    Psychic Whispers
+      You can establish telepathic communication between yourself and
+      others-perfect for quiet infiltration. As an action, choose one
+      or more creatures you can see, up to a number of creatures equal
+      to your proficiency bonus, and then roll one Psionic Energy
+      die. For a number of hours equal to the number rolled, the
+      chosen creatures can speak telepathically with you, and you can
+      speak telepathically with them. To send or receive a message (no
+      action required), you and the other creature must be within 1
+      mile of each other. A creature can't use this telepathy if it
+      can't speak any languages, and a creature can end the telepathic
+      connection at any time (no action required). You and the
+      creature don't need to speak a common language to understand
+      each other.
+      
+      The first time you use this power after each long rest, you
+      don't expend the Psionic Energy die. All other times you use the
+      power, you expend the die.
+    
+    """
+    name = "Psionic Power"
+    source = "Rogue (Soulknife)"
+
+
+class PsychicBlades(Feature):
+    """You can manifest your psionic power as shimmering blades of psychic
+    energy. Whenever you take the Attack action, you can manifest a
+    psychic blade from your free hand and make the attack with that
+    blade. This magic blade is a simple melee weapon with the finesse
+    and thrown properties. It has a normal range of 60 feet and no
+    long range, and on a hit, it deals psychic damage equal to 1d6
+    plus the ability modifier you used for the attack roll. The blade
+    vanishes immediately after it hits or misses its target, and it
+    leaves no mark on its target if it deals damage.
+    
+    After you attack with the blade, you can make a melee or ranged
+    weapon attack with a second psychic blade as a bonus action on the
+    same turn, provided your other hand is free to create it. The
+    damage die of this bonus attack is 1d4, instead of 1d6.
+
+    """
+    name = "Psychic Blades"
+    source = "Rogue (Soulknife)"
+
+
+class SoulBlades(Feature):
+    """Your Psychic Blades are now an expression of your psi-suffused
+    soul, giving you these powers that use your Psionic Energy dice:
+    
+    Homing Strikes
+      If you make an attack roll with your Psychic Blades and miss the
+      target, you can roll one Psionic Energy die and add the number
+      rolled to the attack roll. If this causes the attack to hit, you
+      expend the Psionic Energy die.
+    Psychic Teleportation
+      As a bonus action, you manifest one of your Psychic Blades,
+      expend one Psionic Energy die and roll it, and throw the blade
+      at an unoccupied space you can see, up to a number of feet away
+      equal to 10 times the number rolled. You then teleport to that
+      space, and the blade vanishes.
+    
+    """
+    name = "Soul Blades"
+    source = "Rogue (Soulknife)"
+
+
+class PsychicVeil(Feature):
+    """You can weave a veil of psychic static to mask yourself. As an
+    action, you can magically become invisible, along with anything
+    you are wearing or carrying, for 1 hour or until you dismiss this
+    effect (no action required). This invisibility ends early
+    immediately after you deal damage to a creature or you force a
+    creature to make a saving throw.
+    
+    Once you use this feature, you can't do so again until you finish
+    a long rest, unless you expend a Psionic Energy die to use this
+    feature again.
+    
+    """
+    name = "Psychic Veil"
+    source = "Rogue (Soulknife)"
+
+
+class RendMind(Feature):
+    """You can sweep your Psychic Blades directly through a creature's
+    mind. When you use your Psychic Blades to deal Sneak Attack damage
+    to a creature, you can force that target to make a Wisdom saving
+    throw (DC equal to 8 + your proficiency bonus + your Dexterity
+    modifier). If the save fails, the target is stunned for 1
+    minute. The stunned target can repeat the saving throw at the end
+    of each of its turns, ending the effect on itself on a success.
+
+    Once you use this feature, you can't do so again until you finish
+    a long rest, unless you expend three Psionic Energy dice to use it
+    again.
+
+    """
+    name = "Rend Mind"
+    source = "Rogue (Soulknife)"
+    
