@@ -1,7 +1,8 @@
 """Convenience module holding base classes for the various kinds of
 game mechanics."""
 
-from dungeonsheets.content import Content
+from dungeonsheets.content import Content, Creature
+from dungeonsheets.encounter import Encounter
 from dungeonsheets.spells import Spell
 from dungeonsheets.features import Feature
 from dungeonsheets.infusions import Infusion
@@ -14,5 +15,7 @@ from dungeonsheets.weapons import (
 )
 from dungeonsheets.armor import Armor, Shield
 from dungeonsheets.magic_items import MagicItem
-from dungeonsheets.monsters import Monster
 from dungeonsheets.stats import Ability
+
+from dungeonsheets.character import Character
+from dungeonsheets.monsters import Monster
