@@ -803,24 +803,29 @@ class Slow(Spell):
 
 
 class Snare(Spell):
-    """As you cast this spell, you use the rope to create a circle with a 5-foot radius
-    on the ground or the floor. When you finish casting, the rope disappears and
-    the circle becomes a magic trap.
-    This trap is nearly invisible, requiring a
-    successful Intelligence (Investigation) check against your spell save DC to be
-    discerned.
-    The trap triggers when a Small, Medium, or Large creature moves onto
-    the ground or the floor in the spell's radius. That creature must succeed on a
-    Dexterity saving throw or be magically hoisted into the air, leaving it hanging
-    upside down 3 feet above the ground or the floor. The creature is restrained
-    there until the spell ends.
-    A restrained creature can make a Dexterity saving
-    throw at the end of each of its turns, ending the effect on itself on a success.
-    Alternatively, the creature or someone else who can reach it can use an action
-    to make an Intelligence (Arcana) check against your spell save DC. On a success,
-    the restrained effect ends.
-    After the trap is triggered, the spell ends when no
-    creature is restrained by it.
+    """As you cast this spell, you use the rope to create a circle with a
+    5-foot radius on the ground or the floor. When you finish casting,
+    the rope disappears and the circle becomes a magic trap.
+    
+    This trap is nearly invisible, requiring a successful Intelligence
+    (Investigation) check against your spell save DC to be discerned.
+    
+    The trap triggers when a Small, Medium, or Large creature moves
+    onto the ground or the floor in the spell's radius. That creature
+    must succeed on a Dexterity saving throw or be magically hoisted
+    into the air, leaving it hanging upside down 3 feet above the
+    ground or the floor. The creature is restrained there until the
+    spell ends.
+
+    A restrained creature can make a Dexterity saving throw at the end
+    of each of its turns, ending the effect on itself on a success.
+    Alternatively, the creature or someone else who can reach it can
+    use an action to make an Intelligence (Arcana) check against your
+    spell save DC. On a success, the restrained effect ends.
+
+    After the trap is triggered, the spell ends when no creature is
+    restrained by it.
+
     """
 
     name = "Snare"
