@@ -32,7 +32,43 @@ log = logging.getLogger(__name__)
 
 def mod_str(modifier):
     """Converts a modifier to a string, eg 2 -> '+2'."""
-    return "{:+d}".format(modifier)
+    try:
+        s = "{:+d}".format(modifier)
+    except TypeError:
+        s = "N/A"
+    return s
+
+
+def str_to_list(obj, attr: str, sep: str = ","):
+    """Find the string *obj.attr* if it exists, and returns it as a
+    list.
+
+    Parameters
+    ==========
+    obj
+      Any python object, presumably with an attribute *attr*.
+    attr
+      The name of the attribute to look up.
+    sep
+      The separator to use for splitting the string.
+    
+    Returns
+    =======
+    items
+      A sequence of the items retrieved from *obj.attr* string.  If
+      *obj.attr* does not exist, an empty list will be returned. If
+      *obj.attr* is not a string, then it will be presumed to be a
+      sequence already and returned as is.
+
+    """
+    string = getattr(obj, attr, [])
+    if hasattr(string, "split"):
+        # Convert the string to a list
+        lst = [s.strip() for s in string.split(sep)]
+    else:
+        # A non-string attribute was given, so just return it
+        lst = string
+    return lst
 
 
 def ability_mod_str(character, ability):
@@ -156,13 +192,15 @@ class Skill:
     @property
     def is_proficient(self):
         # Check for proficiency
-        proficiencies = [p.replace("_", " ") for p in self.actor.skill_proficiencies]
-        is_proficient = self.skill_name in proficiencies
+        proficiencies = [p.replace("_", " ").lower() for p in self.actor.skill_proficiencies]
+        is_proficient = self.skill_name.lower() in proficiencies
         return is_proficient
 
     @property
     def is_expertise(self):
-        return self.skill_name in self.actor.skill_expertise
+        expertises = [p.replace("_", " ").lower() for p in self.actor.skill_expertise]
+        is_expertise = self.skill_name.lower() in expertises
+        return is_expertise
 
     @property
     def proficiency_modifier(self):
@@ -182,6 +220,8 @@ class Skill:
     def modifier(self):
         ability = getattr(self.actor, self.ability_name)
         modifier = ability.modifier + self.proficiency_modifier
+        # if self.skill_name == "deception":
+        #     import pdb; pdb.set_trace()
         log.info("%s modifier for '%s': %d", self, self.actor.name, modifier)
         return modifier
 
